/*
 * @copyright   © Copyright 2006-2012, epages GmbH, All Rights Reserved.
 *
 * @module      de_epages.externalcontent.ui.facebook
 *
 * @revision    $$
 */
/*jslint nomen: true*/
/*global define, window*/
define('de_epages/externalcontent/ui/facebook', [
	'jquery/ui/widget',
	'ep',
	'de_epages',
    '$tmpl!./facebook',

	'jquery/i18n'
], function ($, ep, de_epages, template) {
    'use strict';
    // Constants.
    var gClassNames = 'SocialWeb',
        // we need this because facebook doesn't support all language codes which can be selected in our storefront
        languageMap = {
            de_CH : 'de_DE',
            de_AT : 'de_DE',
            de_LU : 'de_DE',
            fr_BE : 'fr_FR',
            fr_CH : 'fr_FR',
            fr_LU : 'fr_FR',
            es_AR : 'es_ES',
            es_BO : 'es_ES',
            es_CO : 'es_ES',
            es_US : 'es_ES',
            it_CH : 'it_IT',
            nl_BE : 'nl_NL',
            ru_UA : 'ru_RU'
        };

    $.widget('ui.externalcontentUiFacebook', {

        options: {
            boxMode: false,
            // Boolean. If true, show like box. If false, show like button.
            url: ep.config.canonicalUrl || ep.config.baseUrl,
            // String. Specifying a site the like button or like box should reference.
            action: 'like',
            // String. Possible values: 'like', 'recommend'.
            layout: 'standard',
            // String. Possible values: 'standard', 'button_count', 'box_count'.
            send: false,
            // Boolean. If true, show "send button".
            width: 450,
            // Integer. Width.
            showFaces: false,
            // Boolean. If true, show profile images of people, who like the site.
            color: 'light',
            // String. Possible values 'light', 'dark'.
            showHeader: false,
            // Boolean. If true, show facebook title in box mode.
            showStream: false,
            // Boolean. If true, show comments and posts of the site as stream in box mode.
            type: 'button'
            // String. Possible values: 'button', 'box'.
        },

        _create: function () {
            var self = this,
                o = self.options,
                region = $.i18n.settings.region.replace(/-/, '_');

            if(languageMap[region]){
                region = languageMap[region];
            }

            if (o.type === 'box') {
                o.boxMode = true;
            }

            // Prepend div with id "fb-root" for Facebook API.
            if (!$('#fb-root').length) {
                $('body').prepend('<div id="fb-root"></div>');

                // AsyncInit, otherwise it is error message flame war in chrome.
                window.fbAsyncInit = function () {
                    window.FB.init();
                };
            }

            // Load Facebook API.
            $.ajax({
                dataType: 'script',
                url: 'https://connect.facebook.net/' + region + '/all.js',
                cache: true
            }).done(function () {
                // Render placeholder.
                self.placeholder = template(o).appendTo(self.element.addClass(gClassNames));
                // Parse placeholder.
                window.FB.XFBML.parse(self.element[0]);
            });
        },

        destroy: function () {
            this.element.removeClass(gClassNames);
            if (this.placeholder) {
                this.placeholder.remove();
            }
            return this._superApply(arguments);
        }

    });

	return de_epages;

});